# New in 0.9.1 (2021-03-20)

## Changes

-   Update Pyro module backend to better enfore usage of `model` and `guide`, automate passing of number of training examples to Pyro modules ([#990])
-   Minimum Pyro version bumped ([#988])
-   Improve docs clarity ([#989])
-   Add glossary to developer user guide ([#999])
-   Add num threads config option to `scvi.settings` ([#1001])
-   Add CellAssign tutorial ([#1004])

## Contributors

-   [@adamgayoso]
-   [@galenxing]
-   [@mjayasur]
-   [@wukathy]

[#1001]: https://github.com/YosefLab/scvi-tools/pull/1001
[#1004]: https://github.com/YosefLab/scvi-tools/pull/1004
[#988]: https://github.com/YosefLab/scvi-tools/pull/988
[#989]: https://github.com/YosefLab/scvi-tools/pull/989
[#990]: https://github.com/YosefLab/scvi-tools/pull/990
[#999]: https://github.com/YosefLab/scvi-tools/pull/999
[@adamgayoso]: https://github.com/adamgayoso
[@galenxing]: https://github.com/galenxing
[@mjayasur]: https://github.com/mjayasur
[@wukathy]: https://github.com/wukathy
